"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApplicationLogger = void 0;
const winston_1 = require("winston");
class ApplicationLogger {
    logger;
    constructor() {
        this.logger = (0, winston_1.createLogger)({
            transports: [new winston_1.transports.Console()],
            format: winston_1.format.combine(winston_1.format.colorize({
                colors: { info: "blue", error: "red" },
                message: true,
            }), winston_1.format.timestamp(), winston_1.format.printf(({ timestamp, level, message }) => {
                return `[${timestamp}] ${level}: ${message}`;
            })),
            exitOnError: false,
            handleExceptions: true,
        });
    }
    debug(context, message) {
        this.logger.debug(message, { context });
    }
    log(context, message) {
        this.logger.info(message, { context });
    }
    error(context, message, error) {
        this.logger.error(JSON.stringify(error), {
            context,
            error: {
                name: error.name,
                message: JSON.stringify(error),
                stack: error.stack,
            },
        });
    }
    warn(context, message) {
        this.logger.warn(message, { context });
    }
}
exports.ApplicationLogger = ApplicationLogger;
//# sourceMappingURL=logger-service.js.map