"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logError = exports.getLogger = void 0;
const logger_1 = require("../logger");
const getLogger = () => {
    return new logger_1.ApplicationLogger();
};
exports.getLogger = getLogger;
/**
 * Logs an error message with the provided context using the ApplicationLogger.
 * @param {any} error - The error object to log.
 * @param {string} methodName - The name of the method that encountered the error.
 * @param {any} props - Additional properties to include in the log context.
 */
const logError = (error, methodName, props) => {
    const logger = (0, exports.getLogger)();
    const context = {
        method: methodName,
        props: JSON.stringify(props),
        errorStack: error instanceof Error ? error.stack : undefined,
    };
    logger.error(context, error.message, error);
};
exports.logError = logError;
//# sourceMappingURL=utils.js.map